@@ -14,7 +14,6 @@ except ImportError:
                         'Please install markdown2.')
         # Ugly but better than nothing :)
         return '<pre>%s</pre>' % text
-    
 
 from html_to_xhtml import html_to_xhtml
 
@@ -49,7 +48,7 @@ class Author(unicode):
 class Post(object):
 
     DEFAULT_ENCODING = u'ascii'
-    DEFAULT_AUTHOR = u'unknown author'
+    DEFAULT_AUTHOR = ''
 
     def __init__(self, f, markup=None):
         if isinstance(f, basestring):
@@ -214,7 +213,8 @@ class Post(object):
 
     def get_html(self):
         if self._markup == 'markdown':
-            return markdown(self.content, html4tags=True)
+            return markdown(self.content, html4tags=True,
+                            extras={'demote-headers': 2})
         elif self._markup == 'html':
             return self.content
         else:
@@ -222,12 +222,19 @@ class Post(object):
 
     def get_xhtml(self):
         if self._markup == 'markdown':
-            return markdown(self.content, html4tags=False)
+            return markdown(self.content, html4tags=False,
+                            extras={'demote-headers': 2})
         elif self._markup == 'html':
             return html_to_xhtml(self.content)
         else:
             assert False, "Unknown type for %r" % self
 
+    def formatted_date(self):
+        if isinstance(self.date, datetime.datetime):
+            return self.date.strftime('%Y-%m-%d %H:%M')
+        else:
+            return self.date.strftime('%Y-%m-%d')
+
     def __cmp__(self, other):
         '''
         >>> file1 = "title: 1\\ndate: 2008-1-1\\n\\ntest"
