@@ -5,7 +5,7 @@ import codecs
 from shutil import copy
 
 import weblog
-from _jinja_environment import jinja_environment
+from template import jinja_environment
 from html_full_url import html_full_url
 from post import Post, PostError
 from load import load_post_list, load_configuration
@@ -25,7 +25,7 @@ def generate_post_html(post_list, output_dir, post_tmpl, params):
             raise IOError('\'%s\' already exists and is not a directory' % dir)
         top_dir = '../../../'
         r = post_tmpl.render(title=post.title,
-                             date=post.date,
+                             date=post.formatted_date(),
                              author=post.author,
                              content=html_full_url(top_dir,
                                                    post.get_html()),
@@ -103,7 +103,12 @@ def command_publish(args, options):
         # Last time the feed was updated
         posts = post_list[:config['feed_limit']]
         if posts:
-            feed_updated = max(p.date for p in posts)
+            def _datetime(d):
+                if isinstance(d, datetime.date):
+                    return datetime.datetime(d.year, d.month, d.day)
+                else:
+                    return d
+            feed_updated = max(_datetime(p.date) for p in posts)
         else:
             feed_updated = datetime.datetime.utcnow()
 
